

/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozdom4java
 *
 * The Initial Developer of the Original Code is
 * Peter Szinek, Lixto Software GmbH, http://www.lixto.com.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Peter Szinek (peter@rubyrailways.com)
 *  Michal Ceresna (michal.ceresna@gmail.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


package org.mozilla.dom.events;

//Java imports
import java.util.*;

//org.w3c imports
import org.w3c.dom.*;
import org.w3c.dom.html2.*;
import org.w3c.dom.html.*;
import org.w3c.dom.events.*;
import org.w3c.dom.traversal.*;
import org.w3c.dom.ranges.*;
import org.w3c.dom.views.*;

//mozdom4java imports
import org.mozilla.dom.*;
import org.mozilla.dom.views.*;

//XPCOM import
import org.mozilla.xpcom.*;


public class MouseEventImpl extends UIEventImpl implements org.w3c.dom.events.MouseEvent
{
    protected MouseEventImpl(nsIDOMMouseEvent mozInst)
    {
        super( mozInst );
    }

    public static MouseEventImpl getDOMInstance(nsIDOMMouseEvent mozInst)
    {
        MouseEventImpl node = (MouseEventImpl) instances.get(mozInst);
        return node == null ? new MouseEventImpl(mozInst) : node;
    }
    
    public nsIDOMMouseEvent getInstance()
    {
        //This was already queryinterfaced, so safe to cast
        return (nsIDOMMouseEvent) moz;
    }
    
    public short getButton()
    {
        int result = getInstance().getButton();
        return (short) result;
    }
    
    public boolean getAltKey()
    {
        boolean result = getInstance().getAltKey();
        return result;
    }
    
    public void initMouseEvent(String typeArg, boolean canBubbleArg, boolean cancelableArg, AbstractView viewArg, int detailArg, int screenXArg, int screenYArg, int clientXArg, int clientYArg, boolean ctrlKeyArg, boolean altKeyArg, boolean shiftKeyArg, boolean metaKeyArg, short buttonArg, EventTarget relatedTargetArg)
    {
        nsIDOMAbstractView mozViewarg = ((AbstractViewImpl) viewArg).getInstance();
        nsIDOMNode casted_Relatedtargetarg =((NodeImpl) relatedTargetArg).getInstance();
        nsIDOMEventTarget mozRelatedtargetarg = (nsIDOMEventTarget) casted_Relatedtargetarg.queryInterface(nsIDOMEventTarget.NS_IDOMEVENTTARGET_IID);
        getInstance().initMouseEvent(typeArg, canBubbleArg, cancelableArg, mozViewarg, detailArg, screenXArg, screenYArg, clientXArg, clientYArg, ctrlKeyArg, altKeyArg, shiftKeyArg, metaKeyArg, buttonArg, mozRelatedtargetarg);
    }
    
    public int getClientY()
    {
        int result = getInstance().getClientY();
        return result;
    }
    
    public int getClientX()
    {
        int result = getInstance().getClientX();
        return result;
    }
    
    public boolean getMetaKey()
    {
        boolean result = getInstance().getMetaKey();
        return result;
    }
    
    public boolean getCtrlKey()
    {
        boolean result = getInstance().getCtrlKey();
        return result;
    }
    
    public boolean getShiftKey()
    {
        boolean result = getInstance().getShiftKey();
        return result;
    }
    
    public int getScreenX()
    {
        int result = getInstance().getScreenX();
        return result;
    }
    
    public int getScreenY()
    {
        int result = getInstance().getScreenY();
        return result;
    }
    
    public EventTarget getRelatedTarget()
    {
        nsIDOMEventTarget result = getInstance().getRelatedTarget();
        return (EventTarget) NodeFactory.getNodeInstance(result);
    }
    
}
