

/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozdom4java
 *
 * The Initial Developer of the Original Code is
 * Peter Szinek, Lixto Software GmbH, http://www.lixto.com.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Peter Szinek (peter@rubyrailways.com)
 *  Michal Ceresna (michal.ceresna@gmail.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


package org.mozilla.dom.html;

//Java imports
import java.util.*;

//org.w3c imports
import org.w3c.dom.*;
import org.w3c.dom.html2.*;
import org.w3c.dom.html.*;
import org.w3c.dom.events.*;
import org.w3c.dom.traversal.*;
import org.w3c.dom.ranges.*;
import org.w3c.dom.views.*;

//mozdom4java imports
import org.mozilla.dom.*;
import org.mozilla.dom.views.*;

//XPCOM import
import org.mozilla.xpcom.*;


public class HTMLObjectElementImpl extends HTMLElementImpl implements org.w3c.dom.html.HTMLObjectElement
{
    protected HTMLObjectElementImpl(nsIDOMHTMLObjectElement mozInst)
    {
        super( mozInst );
    }

    public static HTMLObjectElementImpl getDOMInstance(nsIDOMHTMLObjectElement mozInst)
    {
        HTMLObjectElementImpl node = (HTMLObjectElementImpl) instances.get(mozInst);
        return node == null ? new HTMLObjectElementImpl(mozInst) : node;
    }
    
    public nsIDOMHTMLObjectElement getInstance()
    {
        //This was already queryinterfaced, so safe to cast
        return (nsIDOMHTMLObjectElement) moz;
    }
    
    public String getCodeType()
    {
        String result = getInstance().getCodeType();
        return result;
    }
    
    public HTMLFormElement getForm()
    {
        nsIDOMHTMLFormElement result = getInstance().getForm();
        return (HTMLFormElement) NodeFactory.getNodeInstance(result);
    }
    
    public String getWidth()
    {
        String result = getInstance().getWidth();
        return result;
    }
    
    public void setCodeType(String codeType)
    {
        getInstance().setCodeType(codeType);
    }
    
    public void setWidth(String width)
    {
        getInstance().setWidth(width);
    }
    
    public void setType(String type)
    {
        getInstance().setType(type);
    }
    
    public Document getContentDocument()
    {
        nsIDOMDocument result = getInstance().getContentDocument();
        return (Document) NodeFactory.getNodeInstance(result);
    }
    
    public String getName()
    {
        String result = getInstance().getName();
        return result;
    }
    
    public String getHeight()
    {
        String result = getInstance().getHeight();
        return result;
    }
    
    public int getTabIndex()
    {
        int result = getInstance().getTabIndex();
        return result;
    }
    
    public void setHspace(String hspace)
    {
        getInstance().setHspace(new Integer(hspace).intValue());
    }
    
    public String getCodeBase()
    {
        String result = getInstance().getCodeBase();
        return result;
    }
    
    public String getStandby()
    {
        String result = getInstance().getStandby();
        return result;
    }
    
    public String getData()
    {
        String result = getInstance().getData();
        return result;
    }
    
    public void setTabIndex(int tabIndex)
    {
        getInstance().setTabIndex(tabIndex);
    }
    
    public String getHspace()
    {
        int result = getInstance().getHspace();
        return new Integer(result).toString();
    }
    
    public void setHeight(String height)
    {
        getInstance().setHeight(height);
    }
    
    public String getCode()
    {
        String result = getInstance().getCode();
        return result;
    }
    
    public void setStandby(String standby)
    {
        getInstance().setStandby(standby);
    }
    
    public void setName(String name)
    {
        getInstance().setName(name);
    }
    
    public void setAlign(String align)
    {
        getInstance().setAlign(align);
    }
    
    public String getType()
    {
        String result = getInstance().getType();
        return result;
    }
    
    public String getArchive()
    {
        String result = getInstance().getArchive();
        return result;
    }
    
    public void setDeclare(boolean declare)
    {
        getInstance().setDeclare(declare);
    }
    
    public String getVspace()
    {
        int result = getInstance().getVspace();
        return new Integer(result).toString();
    }
    
    public void setCodeBase(String codeBase)
    {
        getInstance().setCodeBase(codeBase);
    }
    
    public void setUseMap(String useMap)
    {
        getInstance().setUseMap(useMap);
    }
    
    public String getAlign()
    {
        String result = getInstance().getAlign();
        return result;
    }
    
    public void setVspace(String vspace)
    {
        getInstance().setVspace(new Integer(vspace).intValue());
    }
    
    public void setCode(String code)
    {
        getInstance().setCode(code);
    }
    
    public String getUseMap()
    {
        String result = getInstance().getUseMap();
        return result;
    }
    
    public boolean getDeclare()
    {
        boolean result = getInstance().getDeclare();
        return result;
    }
    
    public String getBorder()
    {
        String result = getInstance().getBorder();
        return result;
    }
    
    public void setArchive(String archive)
    {
        getInstance().setArchive(archive);
    }
    
    public void setBorder(String border)
    {
        getInstance().setBorder(border);
    }
    
    public void setData(String data)
    {
        getInstance().setData(data);
    }
    
}
